package com.docus.server.collection.webservice.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.docus.core.util.DateUtil;
import com.docus.core.util.Func;
import com.docus.server.collection.dto.TBasicDto;
import com.docus.server.collection.entity.TBasic;
import com.docus.server.collection.mapper.TBasicMapper;
import com.docus.server.collection.util.Result;
import com.docus.server.collection.util.XmlUtil;
import com.docus.server.collection.webservice.TBasicService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.w3c.dom.Node;

import javax.jws.WebService;
import java.util.Date;
import java.util.HashMap;

/**
 * @BelongsProject: docus-webservice-sdry
 * @BelongsPackage: com.docus.server.collection.webservice
 * @Author: chierhao
 * @CreateTime: 2023-02-25  14:52
 * @Description: TODO
 * @Version: 1.0
 */
@Service
@WebService
public class TBasicServiceImpl implements TBasicService {

    @Autowired
    private TBasicMapper tBasicMapper;

    @Override
    public String setTBasic(String body) {
        System.out.println(body);
        if (Func.isEmpty(body)) {
            return Result.failed(null,"参数为空");
        }
        //解析xml
        TBasicDto tBasicDto = getTBasicDto(body);

        System.out.println(tBasicDto.toString());

        //判断jzh是否重复
        TBasic selectTBasic = tBasicMapper.selectOne(new QueryWrapper<TBasic>().eq("jzh", tBasicDto.getJzh()));
        if (selectTBasic != null) {
            return Result.failed(tBasicDto.getSerialId(),"记帐号已存在");
        }
        //组装数据
        TBasic tBasic=new TBasic();
        tBasic.setJzh(tBasicDto.getJzh());
        tBasic.setInpatientNo(tBasicDto.getInpatientNo());
        tBasic.setAdmissTimes(Integer.parseInt(tBasicDto.getAdmissTimes()));
        tBasic.setName(tBasicDto.getName());
        Date admissDate = Func.parseDate(tBasicDto.getAdmissDate(), DateUtil.PATTERN_DATETIME_MINI);
        tBasic.setAdmissDate(admissDate);
        Date disDate = Func.parseDate(tBasicDto.getDisDate(), DateUtil.PATTERN_DATETIME_MINI);
        tBasic.setDisDate(disDate);
        tBasic.setAdmissDeptName(tBasicDto.getAdmissDeptName());
        tBasic.setDisDeptName(tBasicDto.getDisDeptName());
        tBasic.setAttendingName(tBasicDto.getAttendingName());
        //持久化
        tBasicMapper.insert(tBasic);
        return Result.success(tBasicDto.getSerialId());
    }


    public TBasicDto getTBasicDto(String str) {
        TBasicDto dto=new TBasicDto();
        XmlUtil xml=XmlUtil.of(str);
        Node node=null;
        //id-消息流水号
        node = xml.getNode("/PRPA_HIP0032/id/@extension");
        if(Func.isEmpty(node)){
            dto.setSerialId(node.getNodeValue());
        }
        //住院流水号
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/item/@extension");
        if(Func.isEmpty(node)){
            dto.setJzh(node.getNodeValue());
        }
        //住院号标识
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/id/item/@extension");
        if(Func.isEmpty(node)){
            dto.setInpatientNo( node.getNodeValue());
        }
        //住院次数[]
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/lengthOfStayQuantity[@unit='次']/@value");
        if(Func.isEmpty(node)){
            dto.setAdmissTimes(node.getNodeValue());
        }
        //姓名
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/subject/patient/patientPerson/name/item/part/@value");
        if(Func.isEmpty(node)){
            dto.setName(node.getNodeValue());
        }
        //入院日期时间
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/effectiveTime/low/@value");
        if(Func.isEmpty(node)){
            dto.setAdmissDate(node.getNodeValue());
        }
        //出院日期时间
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/effectiveTime/high/@value");
        if(Func.isEmpty(node)){
            dto.setDisDate(node.getNodeValue());
        }
        //入院诊断科室名称[]
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/component[@displayName='入院诊断']/section/entry[@displayName='入院诊断-西医条目']/observation/performer/assignedEntity/representedOrganization/name");
        if(Func.isEmpty(node)){
            dto.setAdmissDeptName(node.getTextContent());
        }
        //出院诊断科室名称[]
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/component[@displayName='出院诊断']/section/entry[@displayName='出院诊断-西医条目']/observation/performer/assignedEntity/representedOrganization/name");
        if(Func.isEmpty(node)){
            dto.setDisDeptName(node.getTextContent());
        }
        //主治医师[]
        node = xml.getNode("/PRPA_HIP0032/controlActProcess/subject/encounterEvent/authenticator[@displayName='主治医师']/assignedEntity/assignedPerson/name");
        if(Func.isEmpty(node)){
            dto.setAttendingName(node.getTextContent());
        }
        return dto;
    }
}

